import os


def create_key(template, outtype=('nii.gz',), annotation_classes=None):
    if template is None or not template:
        raise ValueError('Template must be a valid format string')
    return template, outtype, annotation_classes


def infotodict(seqinfo):
    """Heuristic evaluator for determining which runs belong where

    allowed template fields - follow python string module:

    item: index within category
    subject: participant id
    seqitem: run number during scanning
    subindex: sub index within group
    """

    #data = create_key('run{item:03d}')
    #info = {data: []}
    #last_run = len(seqinfo)

    t1w = create_key('sub-{subject}/{session}/anat/sub-{subject}_{session}_T1w')
    fmap_ap = create_key('sub-{subject}/{session}/fmap/sub-{subject}_{session}_dir-AP_run-00{item:01d}_epi')
    fmap_pa = create_key('sub-{subject}/{session}/fmap/sub-{subject}_{session}_dir-PA_run-00{item:01d}_epi')
    func_taskss = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-stopsig_run-{item:01d}_bold')
    func_taskss_SBRef = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-stopsig_run-{item:01d}_sbref')
    func_rest_AP = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-restap_run-{item:01d}_bold')
    func_rest_AP_SBRef = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-restap_run-{item:01d}_sbref')
    func_rest_PA = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-restpa_run-{item:01d}_bold')
    func_rest_PA_SBRef = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-restpa_run-{item:01d}_sbref')

    info = {t1w: [], fmap_ap: [], fmap_pa: [], func_taskss: [], func_taskss_SBRef: [], func_rest_AP: [], func_rest_AP_SBRef: [], func_rest_PA: [], func_rest_PA_SBRef: [],}

    for s in seqinfo:
        """
        The namedtuple `s` contains the following fields:

        * total_files_till_now
        * example_dcm_file
        * series_id
        * dcm_dir_name
        * unspecified2
        * unspecified3
        * dim1
        * dim2
        * dim3
        * dim4
        * TR
        * TE
        * protocol_name
        * is_motion_corrected
        * is_derived
        * patient_id
        * study_description
        * referring_physician_name
        * series_description
        * image_type
        """

#        info[data].append(s.series_id)
        #if ('T1w_MPR_vNav_4e' in s.protocol_name) and (s.dim1 == 320) and (s.series_description == 'T1w_MPR_vNav_4e RMS') and (s.image_type == '('ORIGINAL', 'PRIMARY', 'OTHER', 'ND', 'NORM', 'MEAN')'):
        if ('MPRAGE' in s.protocol_name) and (s.dim1 == 256):
            info[t1w].append(s.series_id)
        if ('SpinEchoFieldMap_AP' in s.protocol_name):
            info[fmap_ap].append(s.series_id)
        if ('SpinEchoFieldMap_PA' in s.protocol_name):
            info[fmap_pa].append(s.series_id)
        if ('STOP_SIGNAL' in s.protocol_name) and (s.dim4 > 100):
            info[func_taskss].append(s.series_id)
        if ('STOP_SIGNAL' in s.protocol_name) and (s.dim4 == 1):
            info[func_taskss_SBRef].append(s.series_id)
        if ('rfMRI_REST_AP' in s.protocol_name) and (s.dim4 > 100):
            info[func_rest_AP].append(s.series_id)
        if ('rfMRI_REST_AP' in s.protocol_name) and (s.dim4 == 1):
            info[func_rest_AP_SBRef].append(s.series_id)
        if ('rfMRI_REST_PA' in s.protocol_name) and (s.dim4 > 100):
            info[func_rest_PA].append(s.series_id)
        if ('rfMRI_REST_PA' in s.protocol_name) and (s.dim4 == 1):
            info[func_rest_PA_SBRef].append(s.series_id)
    return info
