import os


def create_key(template, outtype=('nii.gz',), annotation_classes=None):
    if template is None or not template:
        raise ValueError('Template must be a valid format string')
    return template, outtype, annotation_classes


def infotodict(seqinfo):
    """Heuristic evaluator for determining which runs belong where

    allowed template fields - follow python string module:

    item: index within category
    subject: participant id
    seqitem: run number during scanning
    subindex: sub index within group
    """

    #data = create_key('run{item:03d}')
    #info = {data: []}
    #last_run = len(seqinfo)

    t1w = create_key('sub-{subject}/{session}/anat/sub-{subject}_{session}_T1w')
    fmap_ap = create_key('sub-{subject}/{session}/fmap/sub-{subject}_{session}_dir-AP_run-00{item:01d}_epi')
    fmap_pa = create_key('sub-{subject}/{session}/fmap/sub-{subject}_{session}_dir-PA_run-00{item:01d}_epi')
    func_taste = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-taste_run-{item:01d}_bold')
    func_taste_SBRef = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-taste_run-{item:01d}_sbref')
    func_smell = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-smell_run-{item:01d}_bold')
    func_smell_SBRef = create_key('sub-{subject}/{session}/func/sub-{subject}_{session}_task-smell_run-{item:01d}_sbref')

    info = {t1w: [], fmap_ap: [], fmap_pa: [], func_taste: [], func_taste_SBRef: [], func_smell: [], func_smell_SBRef: [],}

    for s in seqinfo:
        """
        The namedtuple `s` contains the following fields:

        * total_files_till_now
        * example_dcm_file
        * series_id
        * dcm_dir_name
        * unspecified2
        * unspecified3
        * dim1
        * dim2
        * dim3
        * dim4
        * TR
        * TE
        * protocol_name
        * is_motion_corrected
        * is_derived
        * patient_id
        * study_description
        * referring_physician_name
        * series_description
        * image_type
        """

#        info[data].append(s.series_id)
        #if ('T1w_MPR_vNav_4e' in s.protocol_name) and (s.dim1 == 320) and (s.series_description == 'T1w_MPR_vNav_4e RMS') and (s.image_type == '('ORIGINAL', 'PRIMARY', 'OTHER', 'ND', 'NORM', 'MEAN')'):
        if ('T1w_MPR' in s.protocol_name) and (s.dim1 == 320) and ('NORM' in s.image_type):
            info[t1w].append(s.series_id)
        if ('SpinEchoFieldMap_AP_FOV208' in s.protocol_name):
            info[fmap_ap].append(s.series_id)
        if ('SpinEchoFieldMap_PA_FOV208' in s.protocol_name):
            info[fmap_pa].append(s.series_id)
        if ('taste' in s.protocol_name) and (s.dim4 > 100):
            info[func_taste].append(s.series_id)
        if ('taste' in s.protocol_name) and (s.dim4 == 1):
            info[func_taste_SBRef].append(s.series_id)
        if ('smell' in s.protocol_name) and (s.dim4 > 100):
            info[func_smell].append(s.series_id)
        if ('smell' in s.protocol_name) and (s.dim4 == 1):
            info[func_smell_SBRef].append(s.series_id)
    return info
